function [handles] = initialize_view_window(handles)
%INITIALIZE_VIEW_WINDOW: Identifies the size of the computer screen and
%modifies the relative sizes of the GUI controls.

% call in the berengui_OpeningFcn with the following line:
%   handles = initialize_view_window(handles);
% place at the end of the function, just  before the line:
%   guidata(hObject, handles);

%% Detecting screen size:

set(0, 'units', 'pixels');
temp = get(0, 'screensize');
screenSize = temp(3:4);

if(screenSize(1) < 700)
    errordlg('Your screen might be too small to properly run this GUI.');
    screenSize(1) = 700;
end


%% Creating alignment sectors

%ideal size:
figSizeIdeal = [1080, 715];
figSize = figSizeIdeal;
    
bS = 140;
if(figSize(1)+bS <= screenSize(1)) %adjust aspect ratio to fit screen
    if(figSize(2)+bS <= screenSize(2))
        %GOOD
    else
        figSize(1) = round((screenSize(2)-bS)/figSize(2).*figSize(1));
        figSize(2) = screenSize(2)-bS;
    end
else
    figSize(2) = round((screenSize(1)-bS)/figSize(1).*figSize(2));
    figSize(1) = screenSize(1)-bS;
end

%setting sizes and positions of the panels:
leftPanPos = [15, 15, ((figSize(1)-45)/(figSizeIdeal(1)-30))*670, ...
    ((figSize(2)-30)/(figSizeIdeal(2)-30))*675];
rightPanPos = [leftPanPos(3)+30, 15, ((figSize(1)-45)/(figSizeIdeal(1)-45))*365, ...
    ((figSize(2)-30)/(figSizeIdeal(2)-30))*675];
leftInsidePanPos = [5, 5, leftPanPos(3)-10, leftPanPos(4)-10];
rightLowPanPos = [5, 5, rightPanPos(3)-10, (rightPanPos(4)-19)/2];
rightHighPanPos = [5, rightLowPanPos(4)+14, rightPanPos(3)-10, (rightPanPos(4)-19)/2];

%setting positions for "psuedo-panels"
leftPanTopMenuPos = [20, leftInsidePanPos(4)-60];
    leftPanTopMenuHspace = 80;
    leftPanTopMenuVspace = 25;
leftPanBottomMenuPos = [20, 10];
    leftPanBottomMenuHspace = 40;
    leftPanBottomMenuVspace = 20;
rightPanMenuPos = [10, rightHighPanPos(4)-70];
    rightPanMenuHspace = 50;
    rightPanMenuVspace = 25;
rightPanPlayCompPos = [10, 10];
    rightPanPlayCompHspace = 50;
rightPanChecksPos = [rightHighPanPos(3)-30, rightHighPanPos(4)-70];
    rightPanChecksVspace = 20;
    
%setting sizes and positions for the graphics areas:
leftPanGraphicsPos = [50, 80, leftInsidePanPos(3)-100, leftInsidePanPos(4)-160];
if(leftPanGraphicsPos(3) < leftPanGraphicsPos(4)*1.3)
    leftPanGraphicsPos(2) = leftPanGraphicsPos(2) + (leftPanGraphicsPos(4) - (leftPanGraphicsPos(3)/1.3))/2;
    leftPanGraphicsPos(4) = leftPanGraphicsPos(3)/1.3;
elseif(leftPanGraphicsPos(3) > leftPanGraphicsPos(4)*1.3)
    leftPanGraphicsPos(1) = leftPanGraphicsPos(1) + (leftPanGraphicsPos(3) - (leftPanGraphicsPos(4)*1.3))/2;
    leftPanGraphicsPos(3) = leftPanGraphicsPos(4)*1.3;
end
leftPanGraphicsHspace = 50;
leftPanGraphicsVspace = 50;
leftPanGraphicsAxesSize = [(leftPanGraphicsPos(3)-leftPanGraphicsHspace)/2, ...
                            (leftPanGraphicsPos(4)-leftPanGraphicsVspace)/2];
                        
rightPanGraphicsPos = [40, 60, rightHighPanPos(3)-80, rightHighPanPos(4)-140];
if(rightPanGraphicsPos(3) < rightPanGraphicsPos(4)*1.3)
    rightPanGraphicsPos(2) = rightPanGraphicsPos(2) + (rightPanGraphicsPos(4) - (rightPanGraphicsPos(3)/1.3))/2;
    rightPanGraphicsPos(4) = rightPanGraphicsPos(3)/1.3;
elseif(rightPanGraphicsPos(3) > rightPanGraphicsPos(4)*1.3)
    rightPanGraphicsPos(1) = rightPanGraphicsPos(1) + (rightPanGraphicsPos(3) - (rightPanGraphicsPos(4)*1.3))/2;
    rightPanGraphicsPos(3) = rightPanGraphicsPos(4)*1.3;
end


%% creating specific positions for uicontrol pieces:

%left panel top menu:
lptm_lbl1 = leftPanTopMenuPos + [leftPanTopMenuHspace*0, leftPanTopMenuVspace*1];
lptm_lbl2 = leftPanTopMenuPos + [leftPanTopMenuHspace*1, leftPanTopMenuVspace*1];
lptm_lbl3 = leftPanTopMenuPos + [leftPanTopMenuHspace*2, leftPanTopMenuVspace*1];
lptm_lbl4 = leftPanTopMenuPos + [leftPanTopMenuHspace*3, leftPanTopMenuVspace*1];
lptm_pop1 = leftPanTopMenuPos + [leftPanTopMenuHspace*0, 0];
lptm_pop2 = leftPanTopMenuPos + [leftPanTopMenuHspace*1, 0];
lptm_pop3 = leftPanTopMenuPos + [leftPanTopMenuHspace*2, 0];
lptm_pop4 = leftPanTopMenuPos + [leftPanTopMenuHspace*3, 0];
lptm_btn1 = leftPanTopMenuPos + [leftPanTopMenuHspace*4, 0];
lptm_btn2 = leftPanTopMenuPos + [leftPanTopMenuHspace*5, 0];

%left panel bottom menu:
lpbm_lbl1 = leftPanBottomMenuPos + [leftPanBottomMenuHspace*0, leftPanBottomMenuVspace*1];
lpbm_edit1= leftPanBottomMenuPos + [leftPanBottomMenuHspace*1, leftPanBottomMenuVspace*1];
lpbm_lbl2 = leftPanBottomMenuPos + [leftPanBottomMenuHspace*2, leftPanBottomMenuVspace*1];
lpbm_sld1 = leftPanBottomMenuPos + [leftPanBottomMenuHspace*3, leftPanBottomMenuVspace*1+5];
lpbm_lbl3 = leftPanBottomMenuPos + [leftPanBottomMenuHspace*0, 0];
lpbm_edit2= leftPanBottomMenuPos + [leftPanBottomMenuHspace*1, 0];
lpbm_lbl4 = leftPanBottomMenuPos + [leftPanBottomMenuHspace*2, 0];
lpbm_sld2 = leftPanBottomMenuPos + [leftPanBottomMenuHspace*3, 5];

%left panel graphics area:
lpga_axes1= leftPanGraphicsPos(1:2) + leftPanGraphicsAxesSize.*[0, 1] + [0, leftPanGraphicsVspace];
lpga_axes2 = leftPanGraphicsPos(1:2) + leftPanGraphicsAxesSize.*[1, 1] + [leftPanGraphicsHspace, leftPanGraphicsVspace];
lpga_axes3 = leftPanGraphicsPos(1:2);
lpga_axes4 = leftPanGraphicsPos(1:2) + leftPanGraphicsAxesSize.*[1, 0] + [leftPanGraphicsHspace, 0];


%right panel menus:
rpm_lbl1 = rightPanMenuPos + [rightPanMenuHspace*0, rightPanMenuVspace*1];
rpm_btn1 = rightPanMenuPos + [rightPanMenuHspace*1, rightPanMenuVspace*1];
rpm_btn2 = rightPanMenuPos + [rightPanMenuHspace*2, rightPanMenuVspace*1];
rpm_btn3 = rightPanMenuPos + [rightPanMenuHspace*3, rightPanMenuVspace*1];
rpm_btn4 = rightPanMenuPos + [rightPanMenuHspace*4, rightPanMenuVspace*1];
rpm_btn5 = rightPanMenuPos + [rightPanMenuHspace*0, 0];
rpm_btn6 = rightPanMenuPos + [rightPanMenuHspace*1, 0];
rpm_btn7 = rightPanMenuPos + [rightPanMenuHspace*2, 0];
rpm_btn8 = rightPanMenuPos + [rightPanMenuHspace*3, 0];
rpm_btn9 = rightPanMenuPos + [rightPanMenuHspace*4, 0];

%right panel play/comp:
rppc_btn1 = rightPanPlayCompPos;
rppc_btn2 = rightPanPlayCompPos + [rightPanPlayCompHspace, 0];

%right panel checks:
rpc_btn1 = rightPanChecksPos - [0, rightPanChecksVspace*0];
rpc_btn2 = rightPanChecksPos - [0, rightPanChecksVspace*1];
rpc_chk1 = rightPanChecksPos - [0, rightPanChecksVspace*2];
rpc_chk2 = rightPanChecksPos - [0, rightPanChecksVspace*3];
rpc_chk3 = rightPanChecksPos - [0, rightPanChecksVspace*4];
rpc_chk4 = rightPanChecksPos - [0, rightPanChecksVspace*5];
rpc_chk5 = rightPanChecksPos - [0, rightPanChecksVspace*6];
rpc_chk6 = rightPanChecksPos - [0, rightPanChecksVspace*7];
rpc_chk7 = rightPanChecksPos - [0, rightPanChecksVspace*8];
rpc_chk8 = rightPanChecksPos - [0, rightPanChecksVspace*9];

%right panel graphics area:
%unecessary, all information is inside of rightPanGraphicsPos


%% assigning defined positions to the existing uicontrols:

%figure and parent panel placement:
set(gcf, 'Position', [25, 25, figSize]);
set(handles.uipanelEventGram1, 'Position', leftPanPos);
set(handles.uipanelEventGram, 'Position', leftInsidePanPos);
set(handles.uipanelmod, 'Position', rightPanPos);
set(handles.uipanelmod1, 'Position', rightHighPanPos);
set(handles.uipanelmod2, 'Position', rightLowPanPos);

P = handles.uipanelEventGram; %set parent for these operations
%left panel top menu:
handles.textExp = set_new_position(handles.textExp, P, lptm_lbl1);
handles.textTalker = set_new_position(handles.textTalker, P, lptm_lbl2);
handles.textCons = set_new_position(handles.textCons, P, lptm_lbl3);
handles.text25 = set_new_position(handles.text25, P, lptm_lbl4);
handles.popexp = set_new_position(handles.popexp, P, lptm_pop1);
handles.poptlk = set_new_position(handles.poptlk, P, lptm_pop2);
handles.popcons = set_new_position(handles.popcons, P, lptm_pop3);
handles.popvows = set_new_position(handles.popvows, P, lptm_pop4);
handles.butOpen = set_new_position(handles.butOpen, P, lptm_btn1);
handles.butPlay = set_new_position(handles.butPlay, P, lptm_btn2);

%left panel bottom menu:
handles.staticTime = set_new_position(handles.staticTime, P, lpbm_lbl1);
handles.staticSNR = set_new_position(handles.staticSNR, P, lpbm_lbl3);
handles.editTime = set_new_position(handles.editTime, P, lpbm_edit1);
handles.editSNR = set_new_position(handles.editSNR, P, lpbm_edit2);
handles.staticCS = set_new_position(handles.staticCS, P, lpbm_lbl2);
handles.staticdB = set_new_position(handles.staticdB, P, lpbm_lbl4);
handles.slideTime = set_new_position(handles.slideTime, P, lpbm_sld1);
handles.slideSNR = set_new_position(handles.slideSNR, P, lpbm_sld2);

%left panel graphics area:
handles.plotAIgram = set_new_full_position(handles.plotAIgram, P, [lpga_axes1, leftPanGraphicsAxesSize]);
handles.plotEventGram = set_new_full_position(handles.plotEventGram, P, [lpga_axes2, leftPanGraphicsAxesSize]);
handles.plotCC = set_new_full_position(handles.plotCC, P, [lpga_axes3, leftPanGraphicsAxesSize]);
handles.plotPI = set_new_full_position(handles.plotPI, P, [lpga_axes4, leftPanGraphicsAxesSize]);

%left panel editNtype: (potentially useless box)
handles.editNtype = set_new_position(handles.editNtype, P, [leftPanPos(3)-60, 0]);

P = handles.uipanelmod1; %set parent for these operations
%right top panel menu:
handles.mod1ntype = set_new_position(handles.mod1ntype, P, rpm_lbl1);
handles.butreg1 = set_new_position(handles.butreg1, P, rpm_btn1);
handles.butmod1 = set_new_position(handles.butmod1, P, rpm_btn2);
handles.butundo1 = set_new_position(handles.butundo1, P, rpm_btn3);
handles.butredo1 = set_new_position(handles.butredo1, P, rpm_btn4);
handles.butUpdateMod1 = set_new_position(handles.butUpdateMod1, P, rpm_btn5);
handles.butSet1 = set_new_position(handles.butSet1, P, rpm_btn6);
handles.butreset1 = set_new_position(handles.butreset1, P, rpm_btn7);
handles.butload1 = set_new_position(handles.butload1, P, rpm_btn8);
handles.butsave1 = set_new_position(handles.butsave1, P, rpm_btn9);

%right top panel play/comp:
handles.butplay1 = set_new_position(handles.butplay1, P, rppc_btn1);
handles.butComp1 = set_new_position(handles.butComp1, P, rppc_btn2);

%right top panel checks:
handles.butZoom1 = set_new_position(handles.butZoom1, P, rpc_btn1);
handles.butPan1 = set_new_position(handles.butPan1, P, rpc_btn2);
handles.mod1reg1 = set_new_position(handles.mod1reg1, P, rpc_chk1);
handles.mod1reg2 = set_new_position(handles.mod1reg2, P, rpc_chk2);
handles.mod1reg3 = set_new_position(handles.mod1reg3, P, rpc_chk3);
handles.mod1reg4 = set_new_position(handles.mod1reg4, P, rpc_chk4);
handles.mod1reg5 = set_new_position(handles.mod1reg5, P, rpc_chk5);
handles.mod1reg6 = set_new_position(handles.mod1reg6, P, rpc_chk6);
handles.mod1reg7 = set_new_position(handles.mod1reg7, P, rpc_chk7);
handles.mod1reg8 = set_new_position(handles.mod1reg8, P, rpc_chk8);

%right top panel graphics:
handles.plotMod1 = set_new_full_position(handles.plotMod1, P, rightPanGraphicsPos);

P = handles.uipanelmod2; %set parent for these operations
%right bottom panel menu:
handles.mod2ntype = set_new_position(handles.mod2ntype, P, rpm_lbl1);
handles.butreg2 = set_new_position(handles.butreg2, P, rpm_btn1);
handles.butmod2 = set_new_position(handles.butmod2, P, rpm_btn2);
handles.butundo2 = set_new_position(handles.butundo2, P, rpm_btn3);
handles.butredo2 = set_new_position(handles.butredo2, P, rpm_btn4);
handles.butUpdateMod2 = set_new_position(handles.butUpdateMod2, P, rpm_btn5);
handles.butSet2 = set_new_position(handles.butSet2, P, rpm_btn6);
handles.butreset2 = set_new_position(handles.butreset2, P, rpm_btn7);
handles.butload2 = set_new_position(handles.butload2, P, rpm_btn8);
handles.butsave2 = set_new_position(handles.butsave2, P, rpm_btn9);

%right bottom panel play/comp
handles.butplay2 = set_new_position(handles.butplay2, P, rppc_btn1);
handles.butComp2 = set_new_position(handles.butComp2, P, rppc_btn2);

%right bottom panel checks:
handles.butZoom2 = set_new_position(handles.butZoom2, P, rpc_btn1);
handles.butPan2 = set_new_position(handles.butPan2, P, rpc_btn2);
handles.mod2reg1 = set_new_position(handles.mod2reg1, P, rpc_chk1);
handles.mod2reg2 = set_new_position(handles.mod2reg2, P, rpc_chk2);
handles.mod2reg3 = set_new_position(handles.mod2reg3, P, rpc_chk3);
handles.mod2reg4 = set_new_position(handles.mod2reg4, P, rpc_chk4);
handles.mod2reg5 = set_new_position(handles.mod2reg5, P, rpc_chk5);
handles.mod2reg6 = set_new_position(handles.mod2reg6, P, rpc_chk6);
handles.mod2reg7 = set_new_position(handles.mod2reg7, P, rpc_chk7);
handles.mod2reg8 = set_new_position(handles.mod2reg8, P, rpc_chk8);

%right bottom panel graphics:
handles.plotMod2 = set_new_full_position(handles.plotMod2, P, rightPanGraphicsPos);

end

%function that sets the position of a uicontrol without affecting its size
%also ensures its parent is set appropriately before performing positioning
function [subHandle] = set_new_position(subHandle, parent, newPos)
    set(subHandle, 'Parent', parent);
    set(subHandle, 'Units', 'pixels');
    curPos = get(subHandle, 'Position');
    set(subHandle, 'Position', [newPos, curPos(3:4)]); 
end

%function that sets the position of a uicontrol, ensures its parent is set
%appropriately before performing positioning
function [subHandle] = set_new_full_position(subHandle, parent, newPos)
    set(subHandle, 'Parent', parent);
    set(subHandle, 'Units', 'pixels');
    set(subHandle, 'Position', newPos);
end