%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% This program plot the event_gram 
% Input: event_gram -- the event_gram to be plotted
%        wav_file -- name of the wav file (for labeling)
%        snr -- signal-to-noise ratio for a red line (for labeling)
%        t_star -- time for the event_gram (for labeling)
%        exp -- the id of the experiment (64 or 16)        
%   Author:      Feipeng Li revised from Marion's code
%   E-mail:      fli2@uiuc.edu
%   Time-stamp:  2007-06-05
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
function plot_event_gram(event_gram, wav_file, snr, t_star, exp)

fontsize = 8; 

global configs;
S = load([configs.syspath '/bin/event_gram/mat/standard.mat']);
frequencies = S.frequencies;

[how_many_filters,how_many_snrs] = size(event_gram);
bmdist = linspace(7.35,30,how_many_filters);
exp4=exp;
snrs = initialize_snrs(exp4); %try to fix size to remove error

% Draw the ccgram figure

set(gca,'FontSize',fontsize)
imagesc(event_gram);%,[0 1]);
colormap(flipud(gray))

snr_star = find(snrs == snr);
t_star_cs = 100*t_star;

set(gca,'YDir','normal')
set(gca,'FontSize',fontsize)

xlabel('SNR [dB]','FontSize',fontsize)
ylabel('Frequency [kHz]','FontSize',fontsize)

name = fix_underscore(wav_file);
name = name([2:end-4]); 

%if exp == '64'  %JBA: the "^" causes an error when title() is executed
    txt=sprintf('Event-gram of %s at t* = %s cs' ,name, num2str(t_star_cs)); %,'FontSize',fontsize+1);
    title(txt);
%else
%   title(sprintf('Event-gram of %s at t^* = %s cs' ,name, num2str(t_star_cs) ),'FontSize',fontsize+1)
%end

set(gca,'YAxisLocation','left','YTick',linspace(1,how_many_filters,11));
set(gca,'YTickLabel',0.1*round(10*frequencies(round(linspace(1,how_many_filters,11)))/1000))
%text(snr_star-5, 30 , ['SNR = ' num2str(snr) ' dB'], 'FontSize',fontsize-2,'FontWeight', 'bold')

set(gca, 'XTick',[6:5:length(snrs)-5]);
set(gca,'XTickLabel',snrs([6:5:end-5]));

if (snr_star>=-20)
    hold on
    line([snr_star snr_star], [1 length(frequencies)], 'Color', 'r', 'Linewidth', 2, 'Linestyle', '--');
    hold off
end

% Dotted SNR lines
%if exp == '64'  %JBA: error under some conditions
if strcmp(exp,'64')
    snrsx = [ 4 6 10 16 24 ];
else
    snrsx = [ 3 6 9 15 21 27 34];
end

hold on
for n = 1:length(snrsx)
    line([snrsx(n) snrsx(n)],[1 length(frequencies)],'LineStyle',':','Color','k');
end
hold off

h_axis1 = gca;
h_axis2=axes('Position',get(h_axis1,'Position'));
set(h_axis2,'FontSize',fontsize)
set(h_axis2,'Color','none');
set(h_axis2,'YAxisLocation','left')
set(h_axis2,'XTick',[]);
set(h_axis2,'YLim',get(h_axis1,'YLim'));
set(h_axis2,'Fontsize', fontsize);
set(h_axis2,'YTick',get(h_axis1,'YTick'),'FontSize',fontsize);
set(h_axis2,'YTickLabel',round(bmdist(round(linspace(1,how_many_filters,11)))))
set(h_axis2,'YAxisLocation','left')
ylabel('Distance along BM [mm]')
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
